@@ -148,15 +148,7 @@ def train(itrial     = 0,
     if split=='trial' or (split=='data' and rank==0):
         os.makedirs(checkpoint_dir, exist_ok=True)
         torch.save(model.state_dict(),state_path)
-    state_path = model
-    return {
-        'loss':test_loss.item(),
-        'loss_tf':test_loss.item() if transform==None else eval(transform).item(),
-        'models':state_path,
-        'data':data,
-        'criterion':criterion,
-        'hyperprms':hyperprms,
-    }
+    return test_loss
 
 def evaluate(device, data, model, criterion, accuracy=False, log_dir=None, output=None, update=False, **kwargs):
     model.eval()
