@@ -97,7 +97,7 @@ def get_fct(category,fct=None):
     }
     return pytorch_dict[category] if fct==None else pytorch_dict[category][fct]
 
-def run_uq(output, log_dir, data, models, hyperprms, loss, dl_type, trial, **kwargs):
+def run_uq(trials, hyperprms, data, output, loss, log_dir, dl_type, trial, **kwargs):
     """
     Execute Monte-Carlo Dropout Algorithm. This function loads the trained model
     architecture and does uncertainty quantification using MC dropout technique.
@@ -121,16 +121,15 @@ def run_uq(output, log_dir, data, models, hyperprms, loss, dl_type, trial, **kwa
     module = importlib.import_module('.' + dl_type.lower(), 'hyppo.dnnmodels.pytorch')
     net = module.get_model(data=data['train'], prms=hyperprms, **kwargs).to(device)
     trained_models = []
-    for i,model in enumerate(models):
-        if type(model)==numpy.str_:
-            trained_models.append(load_model(model,net,device))
-        else:
-            trained_models.append(model)
+    for i in trials:
+        model = os.path.join(log_dir,'checkpoints',output,'%02i.pth.tar' % (i+1))
+        trained_models.append(load_model(model,net,device))
     dropout_rate = hyperprms.get('dropout',0.05)[0]
     if dropout_rate == 0:
         logging.warning('Running uncertainty quantification with dropout rate 0 is not optimal.')
         logging.warning('Dropout rate set to 5% for Monte Carlo dropout UQ analysis as a default.')
-    pred_mean, total_var, confidence_interval = uq_quantifier(output, log_dir, data, trained_models, **kwargs)
+    criterion = hyperprms['loss'](**hyperprms['loss_args'])
+    pred_mean, total_var, confidence_interval = uq_quantifier(output, log_dir, data, trained_models, criterion, **kwargs)
     logging.info('-'*40)
     logging.info('OUTER OBJECTIVE FUNCTION {:>8} TRIALS'.format(len(loss)))
     logging.info('-'*40)
