@@ -21,7 +21,7 @@ from ..train import train_evaluation
 from ..obj_fct import *
 from ..utils import extract_evals, check_surrogate_sample
 
-def gp(config,log_dir,loops,step,rank,xlow,xup,mult,names,
+def gp(config,log_dir,loops,step,rank,xlow,xup,mult,names,istop=None,
        nhof=10,ngen=100,mu=100,cxpb=0.75,indpb=0.1,default={},**kwargs):
     """
     Gaussian Process based surrogate optimization algorithm.
@@ -154,12 +154,14 @@ def gp(config,log_dir,loops,step,rank,xlow,xup,mult,names,
             xselected = check_surrogate_sample(log_dir,step,iloop)
             logging.info('Samples: %s' % xselected)
         # Execute training
-        x_sc = [int(xselected[n])*mult[n] for n in range(samples.shape[1])]
-        x_sc = {name:value for name,value in zip(names,x_sc)}
+        x_sc = {name:int(sample)*scale for name,sample,scale in zip(names,xselected,mult)}
         x_sc = {**x_sc,**default}
         out_path = 'surrogate_%s' % ('_'.join(numpy.array(xselected,dtype=str)))
         res = train_evaluation(x_sc,xselected,output=out_path,**config)
         logging.info('='*40+'\n')
+        # Stopping criteria
+        if istop!=None and len(get_and_fit(log_dir,gpr,out_path,fit=False)[0])>=istop:
+            break
     # Gather results, fit and save GP model
     samples, fvals, Fbest, gpr = get_and_fit(log_dir,gpr,out_path)
         
@@ -219,7 +221,7 @@ def Expected_improvement(x, samples, fvals, gpr):
     answer=-1.*expected_improvement[0,0] #maximize f = minimize -f
     return answer,
 
-def get_and_fit(log_dir,gpr,out_path):
+def get_and_fit(log_dir,gpr,out_path,fit=True):
     """
     Extract results, fit and save GP model.
     """
@@ -230,12 +232,13 @@ def get_and_fit(log_dir,gpr,out_path):
     if len(idxs)>0:
         samples = numpy.delete(samples,idxs[:,0],axis=0)
         fvals   = numpy.delete(fvals,idxs[:,0],axis=0)
-    # Gaussian Process fitting
-    gpr.fit(samples, fvals)
-    # Save surrogate models
-    path = os.path.join(log_dir,'models',out_path)
-    os.makedirs(path,exist_ok=True)
-    with open(path+'/gpr_model.pkl','wb') as f:
-        pickle.dump(gpr,f)
+    if fit:
+        # Gaussian Process fitting
+        gpr.fit(samples, fvals)
+        # Save surrogate models
+        path = os.path.join(log_dir,'models',out_path)
+        os.makedirs(path,exist_ok=True)
+        with open(path+'/gpr_model.pkl','wb') as f:
+            pickle.dump(gpr,f)
     return samples, fvals, Fbest, gpr
 
