@@ -19,8 +19,8 @@ from .phi import phi
 from .InitialRBFMatrices import InitialRBFMatrices, UpdateRBFMatrices
 from .ComputeRBF import ComputeRBF
 
-def rbf(config,log_dir,loops,step,rank,xlow,xup,mult,names,
-        maxshrinkparam=5,succtolerance=3,Ncand=500,default={},**kwargs):
+def rbf(config,log_dir,loops,step,rank,xlow,xup,mult,names,maxshrinkparam=5,istop=None,
+        succtolerance=3,Ncand=500,valweight=1.25,maxvalweight=1,default={},**kwargs):
     """
     Radial Basis Function based surrogate optimization algorithm.    
 
@@ -54,20 +54,6 @@ def rbf(config,log_dir,loops,step,rank,xlow,xup,mult,names,
     out_path = 'original'
     # Initialize RBF class
     rbf = ComputeRBF(**kwargs)
-    # Tolerance parameters
-    tolerance = 0.001 * numpy.min([xup-xlow for xup,xlow in zip(xup,xlow)]) * numpy.linalg.norm(numpy.ones((1, len(mult))))
-    # Algorithm parameters -- delete stuff from here, not necessary for this problem
-    sigma_stdev_default = 1 # integers
-    sigma_stdev         = sigma_stdev_default # current mutation rate
-    failtolerance       = max(5,len(mult))
-    # Initializations
-    shrinkctr           = 0 # number of times sigma_stdev was shrunk
-    failctr             = 0 # number of consecutive unsuccessful iterations
-    localminflag        = 0 # indicates whether or not xbest is at a local minimum
-    succctr             = 0 # number of consecutive successful iterations
-    #p                   = fvals[0, 0]
-    valweight           = 1.25
-    maxvalweight        = 1
     # Print out parameters for generational process
     logging.info('='*40)
     logging.info('RADIAL BASIS FUNCTION PARAMETERS')
@@ -81,8 +67,6 @@ def rbf(config,log_dir,loops,step,rank,xlow,xup,mult,names,
         logging.info('SURROGATE ITERATION {:>3} / {:<3}'.format(iloop+1,loops))
         logging.info('-'*40)
         if rank == 0:
-            if localminflag != 0:
-                break
             # Gather results, fit and save GP model
             samples, fvals, xbest, Fbest = get_fvals(log_dir)
             valweight -= 0.25
@@ -161,7 +145,7 @@ def rbf(config,log_dir,loops,step,rank,xlow,xup,mult,names,
                 CR[:,ii]=numpy.ravel(numpy.random.randint(xlow[ii],xup[ii],(Ncand,1)))
             CandPoint = numpy.concatenate((CP,CR), axis = 0)#all candidate points
             CandValue, NormValue = rbf.fit(CandPoint)
-            xselected, normval = Minimize_Merit_Function(CandPoint, CandValue, NormValue, fvals, tolerance, valweight)
+            xselected, normval = Minimize_Merit_Function(CandPoint, CandValue, NormValue, fvals, valweight)
             xselected = numpy.array(xselected,dtype=int)
             logging.info('Samples: %s' % xselected)
         else:
@@ -171,37 +155,16 @@ def rbf(config,log_dir,loops,step,rank,xlow,xup,mult,names,
             xselected = check_surrogate_sample(log_dir,step,iloop)
             logging.info('Samples: %s' % xselected)
         # Execute training
-        x_sc = [int(xselected[n])*mult[n] for n in range(samples.shape[1])]
-        x_sc = {name:value for name,value in zip(names,x_sc)}
+        x_sc = {name:int(sample)*scale for name,sample,scale in zip(names,xselected,mult)}
         x_sc = {**x_sc,**default}
         out_path = 'surrogate_%s' % ('_'.join(numpy.array(xselected,dtype=str)))
         Fselected = train_evaluation(x_sc,xselected,output=out_path,**config)
         logging.info('='*40+'\n')
+        # Stopping criteria
+        if istop!=None and len(get_fvals(log_dir)[0])>=istop:
+            break
 
-#         if Fselected < Fbest:
-#             if Fbest - Fselected > (1e-3)*math.fabs(Fbest):
-#                 # "significant" improvement
-#                 failctr = 0
-#                 succctr = succctr + 1
-#             else:
-#                 failctr = failctr + 1
-#                 succctr = 0
-#             xbest = xselected
-#             Fbest = Fselecteds
-#             #data.best_Y = best_Y
-#             #best_model = model
-#         else:
-#             failctr = failctr + 1
-#             succctr = 0
-#         check if algorithm is in a local minimum
-#         shrinkflag = 1
-#         if failctr >= failtolerance:
-#            localminflag = 1
-#         if succctr >= succtolerance:
-#            sigma_stdev = min(2 * sigma_stdev, sigma_stdev_default)
-#            succctr = 0
-
-def Minimize_Merit_Function(CandPoint, CandValue, NormValue, fvals, tolerance, valueweight):
+def Minimize_Merit_Function(CandPoint, CandValue, NormValue, fvals, valueweight):
     if fvals.shape[1]>1:
         #CandValue = CandValue[:,0] #mean value computed for each candiate point of the rbf ensembles
         CandValue = CandValue[:,0]+2*CandValue[:,1] #mean + 2std  
@@ -221,7 +184,7 @@ def Minimize_Merit_Function(CandPoint, CandValue, NormValue, fvals, tolerance, v
     # compute weighted score for all candidates
     CandTotalValue = valueweight * ScaledCandValue + (1 - valueweight) * ScaledCandMinDist
     # assign bad scores to candidate points that are too close to already sampled points
-    CandTotalValue[CandMinDist < tolerance] = numpy.inf
+    CandTotalValue[CandMinDist < 1] = numpy.inf
     MinCandTotalValue = numpy.amin(CandTotalValue)
     selindex = numpy.argmin(CandTotalValue)
     xselected = numpy.array(CandPoint[selindex, :])
