@@ -13,7 +13,7 @@ from .extract import get_samples
 def slurm(config,**kwargs):
     make_slurm_script(config['path'],**config['dist'])
     
-def make_slurm_script(path, sbatch={}, operation='evaluation', log_dir='logs', nsteps=1, ntasks=1,
+def make_slurm_script(path, sbatch={}, operation='evaluation', nsteps=1, ntasks=1,
                       node_type='cpu', module=None, conda='', cd=None, export=None, 
                       proc_per_node=None, **kwargs):
     if proc_per_node==None:
@@ -53,13 +53,12 @@ def make_slurm_script(path, sbatch={}, operation='evaluation', log_dir='logs', n
     # ----------------------------------------------
     if cd!=None:
         script.write('cd %s\n' % cd)
-    script.write('mkdir -p %s\n' % log_dir)
     if operation=='evaluation':
         script.write('python $HOME/hyppo/bin/hyppo sampling config.yaml\n')
     # ----------------------------------------------
     #   Parallel SRUN command
     # ----------------------------------------------
-    parallel = 'parallel --delay .2 -j %i --joblog %s/runtask.log' % (nsteps, log_dir)
+    parallel = 'parallel --delay .2 -j %i' % nsteps
     srun = 'srun --exclusive --nodes 1 --ntasks %i --%ss-per-task 1' % (ntasks, node_type)
     hpo = 'python $HOME/hyppo/bin/hyppo %s config.yaml' % operation
     script.write('%s "%s %s %s && echo step {1}" ::: {0..%i}\n' % (parallel, conda, srun, hpo, nsteps-1))
