@@ -151,6 +151,66 @@ def model_visualization_2d(X,Y,path,evaluation,surrogate,imax=10,sigma=False):
         plt.savefig('%s/plots/iter_%02i' % (path,i+1))
         plt.close()
     
+    
+def scatter_solutions(input_data,save=True,show=False,**kwargs):
+    """
+    Scatter plot of all evaluated HPO solutions. A top histogram is also displayed
+    to show the distribution of losses found across all solutions. Multiple set of
+    HPO solutions can be displayed next to each other, see examples.
+    
+    Parameters
+    ----------
+    input_data : :class:`list`
+        Input extracted list of solutions.
+    save : :class:`bool`
+        Save the figure into a PDF with filename figure.pdf
+    show : :class:`bool`
+        Display figure.
+        
+    Examples
+    --------
+    A simple example of the ``input_data`` list can be as follows:
+    
+    >>> input_data = [solutions]
+    
+    where ``solutions`` is a set of solutions extracted from the saved log files
+    using the :method:`hyppo.extract` function.
+    
+    
+    More than one datasets can also be considered. For instance, let's consider two
+    set of solutions, one, ``data1``, contains solutions obtained using Gaussian
+    Process surrogate modeling, the other, ``data2``, are solutions obtained doing
+    only random sampling, the ``input_data`` can be built as follows:
+    
+    >>> input_data = [[data1,'Gaussian Process'],[data2,'Random Sampling']]
+    """
+    plt.style.use('seaborn')
+    fig, ax = plt.subplots(2,len(input_data),figsize=(4*len(input_data)+2,5),gridspec_kw={'height_ratios': [1, 3]},dpi=200,sharex=True,sharey='row')
+    if len(input_data)==1:
+        ax = numpy.array(ax,ndmin=2).T
+    plt.subplots_adjust(left=0.05,top=0.93,right=0.9,wspace=0.05,hspace=0.1)
+    for i,data in enumerate(input_data):
+        if type(data)==list:
+            data, title = data
+            ax[0][i].set_title('(%i) %s' % (i+1,title))
+        print('Dataset %i : %i solutions displayed' % (i+1,len(data)))
+        ax[0][i].hist(data.loss,range=[0,1.6],rwidth=0.9,bins=16,histtype='bar')
+        im = ax[1][i].scatter(data.loss,data.stdev,c=data.hp3*5e-5,lw=0.1,alpha=0.5,s=20,cmap='plasma')
+        ax[1][i].minorticks_off()
+        ax[1][i].set_xlabel('Best Wasserstein Distance')
+        # ax[i].set_xlim([0,0.25])
+        # ax[i].set_ylim([0,0.1])
+        ax[1][i].scatter([0.125],[0.030], facecolors='none', edgecolors='tomato',s=1200,lw=2)
+    ax[1][0].set_ylabel(r'1-$\mathrm{\sigma}$ Deviation')
+    cax = plt.axes([0.91, 0.125, 0.02, 0.575])
+    cbar = plt.colorbar(im,cax=cax,format='%.0e')
+    cbar.set_alpha(1)
+    cbar.draw_all()
+    cbar.set_label('Generator Learning Rate')
+    if save: plt.savefig('figure.pdf')
+    if show: plt.show()
+    plt.close()
+    
 # class PlotResults():
     
 #     def __init__(self, data, y_predicted, output_name):
